# Copyright (c) 2000-2012, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_without repolib

%define repodir %{_javadir}/repository.jboss.com/org/jboss/logmanager/%{namedversion}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%define section free
%define reltag .GA
%define patchtag -patch-01
%define brewreltag %{reltag}_patch_01
%define namedversion %{version}%{reltag}%{patchtag}

Name:           jboss-logmanager
Version:        1.1.2
Release:        6%{brewreltag}%{?dist}
Epoch:          0
Summary:        JBoss Log Manager
License:        LGPLv2+
Group:          Development/Java
URL:            https://github.com/dmlloyd/jboss-logmanager/tree/1.1.2.GA
Source0:        jboss-logmanager-1.1.2.GA.tar.gz
Source1:        jboss-logmanager-jpp-depmap.xml
Source2:        jboss-logmanager-settings.xml
Source3:        jboss-logmanager-component-info.xml

Patch0:         jboss-logmanager-pom.patch
# patch for https://issues.jboss.org/browse/JBPAPP-8851
# https://github.com/jboss-logging/jboss-logmanager/commit/9f1033d05298b3c49aaad2dddf94a7f2256da861
Patch1:         jboss-logmanager-LogManager.patch

BuildArch:      noarch
Requires(post): jpackage-utils >= 0:1.7.3
Requires(postun): jpackage-utils >= 0:1.7.3
BuildRequires:  jpackage-utils >= 0:1.7.3
BuildRequires:  java-devel >= 0:1.5.0
BuildRequires:	jboss-common-core
BuildRequires:  jboss-parent
BuildRequires:  maven2 >= 0:2.0.7
BuildRequires:  maven2-plugin-compiler
BuildRequires:  maven2-plugin-install
BuildRequires:  maven2-plugin-jar
BuildRequires:  maven2-plugin-javadoc
BuildRequires:  maven2-plugin-resources
BuildRequires:  maven2-plugin-source
BuildRequires:  maven-deploy-plugin
BuildRequires:  maven-doxia-sitetools
BuildRequires:  maven-release-plugin
BuildRequires:	surefire
BuildRequires:  maven-surefire-plugin
BuildRequires:  surefire-providers
BuildRequires:  surefire-testng
BuildRequires:	testng
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
JBoss Log Manager.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
%{summary}.

%if %with repolib
%package repolib
Summary:        Artifacts to be uploaded to a repository library
Group:          Development/Libraries/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%prep
%setup -q -n %{name}-%{version}%{reltag}
%patch0 -p1
%patch1 -p1
%{_bindir}/find . -name "*.jar" | %{_bindir}/xargs -t %{__rm} -f

cp -p %{SOURCE2} maven2-settings.xml

sed -i -e "s|<url>__JPP_URL_PLACEHOLDER__</url>|<url>file://`pwd`/m2_repo/repository</url>|g" maven2-settings.xml
sed -i -e "s|<url>__JAVADIR_PLACEHOLDER__</url>|<url>file://`pwd`/external_repo</url>|g" maven2-settings.xml
sed -i -e "s|<url>__MAVENREPO_DIR_PLACEHOLDER__</url>|<url>file://`pwd`/m2_repo/repository</url>|g" maven2-settings.xml
sed -i -e "s|<url>__MAVENDIR_PLUGIN_PLACEHOLDER__</url>|<url>file:///usr/share/maven2/plugins</url>|g" maven2-settings.xml
sed -i -e "s|<url>__ECLIPSEDIR_PLUGIN_PLACEHOLDER__</url>|<url>file:///usr/share/eclipse/plugins</url>|g" maven2-settings.xml

mkdir external_repo
ln -s %{_javadir} external_repo/JPP

%build
export M2SETTINGS=$(pwd)/maven2-settings.xml
export MAVEN_REPO_LOCAL=$(pwd)/m2_repo/repository

mvn-jpp -e \
        -s ${M2SETTINGS} \
        -Dmaven.repo.local=$MAVEN_REPO_LOCAL \
        -Dmaven2.jpp.depmap.file=%{SOURCE1} \
		-Dmaven.test.failure.ignore=true \
        -DaltDeploymentRepository=jboss-releases::default::file://$(pwd)/maven2-brew \
        install deploy:deploy javadoc:javadoc

%install
rm -rf $RPM_BUILD_ROOT

# jars
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}
install -m 644 target/%{name}-%{namedversion}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-%{namedversion}.jar
%add_to_maven_depmap org.jboss.logmanager %{name} %{namedversion} JPP %{name}
install -m 644 target/%{name}-%{namedversion}-sources.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-sources-%{namedversion}.jar
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}*; do ln -sf ${jar} `echo $jar| sed  "s|-%{namedversion}||g"`; done)

# pom
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/maven2/poms
install -m 644 pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}.pom

# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -rf target/site/apidocs/* \
                  $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}

%if %with repolib
%{__mkdir_p} %{buildroot}%{_javadir}/repository.jboss.com/maven2-brew
%{__cp} -pr maven2-brew/* %{buildroot}%{_javadir}/repository.jboss.com/maven2-brew

install -d -m 755 $RPM_BUILD_ROOT%{repodir}
install -d -m 755 $RPM_BUILD_ROOT%{repodirlib}
install -p -m 644 %{SOURCE3} $RPM_BUILD_ROOT%{repodir}/component-info.xml
sed -i 's/@VERSION@/%{namedversion}-brew/g' $RPM_BUILD_ROOT%{repodir}/component-info.xml
tag=`echo %{name}-%{version}-%{release} | sed 's|\.|_|g'`
sed -i "s/@TAG@/$tag/g" $RPM_BUILD_ROOT%{repodir}/component-info.xml
install -d -m 755 $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 644 %{SOURCE0} $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 644 %{SOURCE1} $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 644 %{SOURCE2} $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 644 %{PATCH0} $RPM_BUILD_ROOT%{repodirsrc}
cp -p $RPM_BUILD_ROOT%{_javadir}/%{name}.jar $RPM_BUILD_ROOT%{repodirlib}/jboss-logmanager.jar
cp -p $RPM_BUILD_ROOT%{_javadir}/%{name}-sources.jar $RPM_BUILD_ROOT%{repodirlib}/jboss-logmanager-sources.jar
cp -p pom.xml $RPM_BUILD_ROOT%{repodirlib}/jboss-logmanager.pom
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(0644,root,root,0755)
%{_javadir}*/%{name}-%{namedversion}.jar
%{_javadir}*/%{name}.jar
%{_javadir}*/%{name}-sources-%{namedversion}.jar
%{_javadir}*/%{name}-sources.jar
%{_datadir}/maven2/poms/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%if %with repolib
%files repolib
%defattr(0644,root,root,0755)
%{_javadir}*/repository.jboss.com
%endif

%changelog
* Tue May 29 2012 Martha Benitez <mbenitez@redhat.com> - 0:1.1.2-6.GA_patch_01
- Fix version in pom.xml

* Tue May 29 2012 Martha Benitez <mbenitez@redhat.com> - 0:1.1.2-5.GA_patch_01
- Change version to reflect backported fix for JBPAPP-8851

* Tue May 15 2012 Yong Yang <yyang@redhat.com> - 0:1.1.2-4
- Add patch to fix JBPAPP-8851

* Thu Mar 24 2011 Fernando Nasser <fnasser@redhat.com> - 0:1.1.2-3
- Fix jboss-parent version

* Wed Mar 23 2011 Permaine Cheung <pcheung@redhat.com> - 0:1.1.2-2.GA
- Fix Version tag

* Tue Feb 15 2011 Weinan Li <weli@redhat.com> - 0:1.1.2.GA-1
- Upgrade to 1.1.2.GA

* Tue Nov 30 2010 Martha Benitez <mbenitez@redhat.com> - 0:1.1.0-3
- Build with maven 2.2.1
- Change BR maven-release to maven-release-plugin
- Add BR maven-deploy-plugin, maven-surefire-provider-testng
- Add sources jar to main and repolib packages

* Mon May 17 2010 Martha Benitez <mbenitez@redhat.com> - 0:1.1.0-2.1.1
- rebuilt

* Tue Apr 20 2010 Yiqiao Wang <yiwang@redhat.com> 0:1.1.0-2.1
- Rebuild
- Create a depmap entry for testng 

* Fri Aug 28 2009 Martha Benitez <mbenitez@redhat.com> 0:1.1.0-1
- Upgrade to 1.1.0.GA
- Add BR jboss-common-core, testng, maven-surefire
- Add maven.test.failure.ignore=true
- Add pom.xml to repolib

* Thu Jun 18 2009 David Walluck <dwalluck@redhat.com>  0:1.0.0-2
- add repolib

* Thu Jun 11 2009 Ralph Apel <r.apel@r-apel.de> - 0:1.0.0-1.jpp5
- first release

